@@ -641,8 +641,7 @@ write_properties( VipsForeignSaveDz *dz )
 {
 	GsfOutput *out;
 
-	out = vips_gsf_path( dz->tree, 
-		"ImageProperties.xml", dz->root_name, NULL ); 
+	out = vips_gsf_path( dz->tree, "ImageProperties.xml", NULL ); 
 
 	gsf_output_printf( out, "<IMAGE_PROPERTIES "
 		"WIDTH=\"%d\" HEIGHT=\"%d\" NUMTILES=\"%d\" "
@@ -1031,6 +1030,7 @@ strip_init( Strip *strip, Layer *layer )
 
 	if( !(strip->image = vips_image_new_from_memory( 
 		VIPS_REGION_ADDR( layer->strip, 0, line.top ),
+		VIPS_IMAGE_SIZEOF_LINE( layer->image ) * line.height,
 		line.width, line.height, 
 		layer->image->Bands, layer->image->BandFmt )) ) {
 		strip_free( strip );
@@ -1588,7 +1588,7 @@ vips_foreign_save_dz_build( VipsObject *object )
 
 		background = vips_array_double_newv( 1, 255.0 );
 		g_object_set( object, "background", background, NULL );
-		vips_area_unref( background ); 
+		vips_area_unref( VIPS_AREA( background ) ); 
 	}
 
 	if( dz->overlap >= dz->tile_size ) {
@@ -1700,11 +1700,13 @@ vips_foreign_save_dz_build( VipsObject *object )
 	if( (p = strrchr( dz->basename, '.' )) ) {
 		*p = '\0';
 
-		/* If we're writing to thing.zip, default to zip container.
+		/* If we're writing to thing.zip or thing.szi, default to zip 
+		 * container.
 		 */
-		if( strcasecmp( p + 1, "zip" ) == 0 &&
-			!vips_object_argument_isset( object, "container" ) )
-			dz->container = VIPS_FOREIGN_DZ_CONTAINER_ZIP;
+		if( !vips_object_argument_isset( object, "container" ) )
+			if( strcasecmp( p + 1, "zip" ) == 0 ||
+				strcasecmp( p + 1, "szi" ) == 0 )
+				dz->container = VIPS_FOREIGN_DZ_CONTAINER_ZIP;
 	}
 }
 
@@ -1961,7 +1963,7 @@ vips_foreign_save_dz_class_init( VipsForeignSaveDzClass *class )
 		_( "Rotate image during save" ),
 		VIPS_ARGUMENT_OPTIONAL_INPUT,
 		G_STRUCT_OFFSET( VipsForeignSaveDz, angle ),
-		VIPS_TYPE_ANGLE, VIPS_ANGLE_0 ); 
+		VIPS_TYPE_ANGLE, VIPS_ANGLE_D0 ); 
 
 	VIPS_ARG_ENUM( class, "container", 15, 
 		_( "Container" ), 
@@ -2020,7 +2022,7 @@ vips_foreign_save_dz_init( VipsForeignSaveDz *dz )
 	dz->tile_size = 256;
 	dz->tile_count = 0;
 	dz->depth = VIPS_FOREIGN_DZ_DEPTH_1PIXEL; 
-	dz->angle = VIPS_ANGLE_0; 
+	dz->angle = VIPS_ANGLE_D0; 
 	dz->container = VIPS_FOREIGN_DZ_CONTAINER_FS; 
 }
 
