@@ -59,6 +59,8 @@
  * 	- don't write to our input buffer, thanks Lovell
  * 9/9/14
  * 	- support "none" as a resolution unit
+ * 16/10/14
+ * 	- add "autorotate" option
  */
 
 /*
@@ -158,6 +160,11 @@ typedef struct _ReadJpeg {
 	/* Track the y pos during a read with this.
 	 */
 	int y_pos;
+
+	/* Use Orientation exif tag to automatically rotate and flip image
+	 * during load.
+	 */
+	gboolean autorotate;
 } ReadJpeg;
 
 static int
@@ -211,7 +218,8 @@ readjpeg_close( VipsObject *object, ReadJpeg *jpeg )
 }
 
 static ReadJpeg *
-readjpeg_new( VipsImage *out, int shrink, gboolean fail, gboolean readbehind )
+readjpeg_new( VipsImage *out, 
+	int shrink, gboolean fail, gboolean readbehind, gboolean autorotate )
 {
 	ReadJpeg *jpeg;
 
@@ -224,13 +232,12 @@ readjpeg_new( VipsImage *out, int shrink, gboolean fail, gboolean readbehind )
 	jpeg->readbehind = readbehind;
 	jpeg->filename = NULL;
 	jpeg->decompressing = FALSE;
-
         jpeg->cinfo.err = jpeg_std_error( &jpeg->eman.pub );
 	jpeg->eman.pub.error_exit = vips__new_error_exit;
 	jpeg->eman.pub.output_message = vips__new_output_message;
 	jpeg->eman.fp = NULL;
-
 	jpeg->y_pos = 0;
+	jpeg->autorotate = autorotate;
 
 	/* jpeg_create_decompress() can fail on some sanity checks. Don't
 	 * readjpeg_free() since we don't want to jpeg_destroy_decompress().
@@ -966,6 +973,37 @@ read_jpeg_generate( VipsRegion *or,
 	return( 0 );
 }
 
+#define ORIENTATION ("exif-ifd0-Orientation")
+
+/* Auto-rotate, if rotate_image is set.
+ */
+static VipsImage *
+read_jpeg_rotate( VipsObject *process, VipsImage *im )
+{
+	VipsImage **t = (VipsImage **) vips_object_local_array( process, 2 );
+	VipsAngle angle = vips_autorot_get_angle( im );
+
+	if( angle != VIPS_ANGLE_D0 ) {
+		/* Need to copy to memory or disc, we have to stay seq.
+		 */
+		const guint64 image_size = VIPS_IMAGE_SIZEOF_IMAGE( im );
+		const guint64 disc_threshold = vips_get_disc_threshold();
+
+		if( image_size > disc_threshold ) 
+			t[0] = vips_image_new_temp_file( "%s.v" );
+		else
+			t[0] = vips_image_new_memory();
+
+		if( vips_image_write( im, t[0] ) ||
+			vips_rot( t[0], &t[1], angle, NULL ) )
+			return( NULL );
+		im = t[1];
+		(void) vips_image_remove( im, ORIENTATION );
+	}
+
+	return( im );
+}
+
 /* Read a cinfo to a VIPS image.
  */
 static int
@@ -975,6 +1013,8 @@ read_jpeg_image( ReadJpeg *jpeg, VipsImage *out )
 	VipsImage **t = (VipsImage **) 
 		vips_object_local_array( VIPS_OBJECT( out ), 3 );
 
+	VipsImage *im;
+
 	/* Here for longjmp() from vips__new_error_exit().
 	 */
 	if( setjmp( jpeg->eman.jmp ) ) 
@@ -1002,41 +1042,24 @@ read_jpeg_image( ReadJpeg *jpeg, VipsImage *out )
 			"access", jpeg->readbehind ? 
 				VIPS_ACCESS_SEQUENTIAL : 
 				VIPS_ACCESS_SEQUENTIAL_UNBUFFERED,
-			NULL ) ||
-		vips_image_write( t[1], out ) )
+			NULL ) )
+		return( -1 );
+
+	im = t[1];
+	if( jpeg->autorotate )
+		im = read_jpeg_rotate( VIPS_OBJECT( out ), im );
+
+	if( vips_image_write( im, out ) )
 		return( -1 );
 
 	return( 0 );
 }
 
-/* Read a JPEG file into a VIPS image.
+/* Read the jpeg from file or buffer.
  */
-int
-vips__jpeg_read_file( const char *filename, VipsImage *out, 
-	gboolean header_only, int shrink, gboolean fail, gboolean readbehind )
+static int
+vips__jpeg_read( ReadJpeg *jpeg, VipsImage *out, gboolean header_only )
 {
-	ReadJpeg *jpeg;
-	int result;
-
-	if( !(jpeg = readjpeg_new( out, shrink, fail, readbehind )) )
-		return( -1 );
-
-	/* Here for longjmp() from vips__new_error_exit() during startup.
-	 */
-	if( setjmp( jpeg->eman.jmp ) ) {
-		(void) readjpeg_free( jpeg );
-
-		return( -1 );
-	}
-
-	/* Set input to file.
-	 */
-	if( readjpeg_file( jpeg, filename ) ) {
-		(void) readjpeg_free( jpeg );
-
-		return( -1 );
-	}
-
 	/* Need to read in APP1 (EXIF metadata), APP2 (ICC profile), APP13
 	 * (photoshop IPCT).
 	 */
@@ -1046,15 +1069,59 @@ vips__jpeg_read_file( const char *filename, VipsImage *out,
 
 	/* Convert!
 	 */
-	if( header_only )
-		result = read_jpeg_header( jpeg, out );
-	else
-		result = read_jpeg_image( jpeg, out );
+	if( header_only ) {
+		if( read_jpeg_header( jpeg, out ) )
+			return( -1 ); 
 
-	/* Don't call readjpeg_free(), we're probably still live.
+		/* Swap width and height if we're going to rotate this image.
+		 */
+		if( jpeg->autorotate ) { 
+			VipsAngle angle = vips_autorot_get_angle( out ); 
+
+			if( angle == VIPS_ANGLE_D90 || 
+				angle == VIPS_ANGLE_D270 )
+				VIPS_SWAP( int, out->Xsize, out->Ysize );
+
+			/* We won't be returning an orientation tag.
+			 */
+			(void) vips_image_remove( out, ORIENTATION );
+		}
+	}
+	else {
+		if( read_jpeg_image( jpeg, out ) )
+			return( -1 );
+	}
+
+	return( 0 );
+}
+
+/* Read a JPEG file into a VIPS image.
+ */
+int
+vips__jpeg_read_file( const char *filename, VipsImage *out, 
+	gboolean header_only, int shrink, gboolean fail, gboolean readbehind,
+	gboolean autorotate )
+{
+	ReadJpeg *jpeg;
+
+	if( !(jpeg = readjpeg_new( out, 
+		shrink, fail, readbehind, autorotate )) )
+		return( -1 );
+
+	/* Here for longjmp() from vips__new_error_exit() during startup.
 	 */
+	if( setjmp( jpeg->eman.jmp ) ) 
+		return( -1 );
 
-	return( result );
+	/* Set input to file.
+	 */
+	if( readjpeg_file( jpeg, filename ) ) 
+		return( -1 );
+
+	if( vips__jpeg_read( jpeg, out, header_only ) ) 
+		return( -1 );
+
+	return( 0 );
 }
 
 /* Just like the above, but we read from a memory buffer.
@@ -1231,40 +1298,26 @@ readjpeg_buffer (ReadJpeg *jpeg, void *buf, size_t len)
 
 int
 vips__jpeg_read_buffer( void *buf, size_t len, VipsImage *out, 
-	gboolean header_only, int shrink, int fail, gboolean readbehind )
+	gboolean header_only, int shrink, int fail, gboolean readbehind, 
+	gboolean autorotate )
 {
 	ReadJpeg *jpeg;
-	int result;
 
-	if( !(jpeg = readjpeg_new( out, shrink, fail, readbehind )) )
+	if( !(jpeg = readjpeg_new( out, 
+		shrink, fail, readbehind, autorotate )) )
 		return( -1 );
 
-	if( setjmp( jpeg->eman.jmp ) ) {
-		(void) readjpeg_free( jpeg );
-
+	if( setjmp( jpeg->eman.jmp ) ) 
 		return( -1 );
-	}
 
 	/* Set input to buffer.
 	 */
 	readjpeg_buffer( jpeg, buf, len );
 
-	/* Need to read in APP1 (EXIF metadata) and APP2 (ICC profile).
-	 */
-	jpeg_save_markers( &jpeg->cinfo, JPEG_APP0 + 1, 0xffff );
-	jpeg_save_markers( &jpeg->cinfo, JPEG_APP0 + 2, 0xffff );
+	if( vips__jpeg_read( jpeg, out, header_only ) ) 
+		return( -1 );
 
-	/* Convert!
-	 */
-	if( header_only )
-		result = read_jpeg_header( jpeg, out );
-	else
-		result = read_jpeg_image( jpeg, out );
-
-	/* Don't call readjpeg_free(), we're probably still live.
-	 */
-
-	return( result );
+	return( 0 );
 }
 
 int
