@@ -148,6 +148,10 @@
  * 	- add read from buffer
  * 30/4/14
  * 	- 1/2/4 bit palette images can have alpha
+ * 27/10/14 Lovell
+ * 	- better istiff detector spots bigtiff
+ * 3/12/14
+ * 	- read any XMP metadata
  */
 
 /*
@@ -1139,6 +1143,19 @@ parse_header( ReadTiff *rtiff, VipsImage *out )
 			(VipsCallbackFn) vips_free, data_copy, data_length );
 	}
 
+	/* Read any XMP metadata.
+	 */
+	if( TIFFGetField( rtiff->tiff, 
+		TIFFTAG_XMLPACKET, &data_length, &data ) ) {
+		void *data_copy;
+
+		if( !(data_copy = vips_malloc( NULL, data_length )) ) 
+			return( -1 );
+		memcpy( data_copy, data, data_length );
+		vips_image_set_blob( out, VIPS_META_XMP_NAME, 
+			(VipsCallbackFn) vips_free, data_copy, data_length );
+	}
+
 	return( 0 );
 }
 
@@ -1672,7 +1689,7 @@ readtiff_new( VipsImage *out, int page, gboolean readbehind )
 	g_signal_connect( out, "close", 
 		G_CALLBACK( readtiff_destroy ), rtiff ); 
 
-	if( rtiff->page < 0 || rtiff->page > 1000 ) {
+	if( rtiff->page < 0 || rtiff->page > 1000000 ) {
 		vips_error( "tiff2vips", _( "bad page number %d" ),
 			rtiff->page );
 		return( NULL );
@@ -1904,9 +1921,11 @@ vips__istiff_buffer( void *buf, size_t len )
 {
 	char *str = (char *) buf; 
 
-	if( len >= 2 &&
-		((str[0] == 'M' && str[1] == 'M') ||
-		 (str[0] == 'I' && str[1] == 'I')) ) 
+	if( len >= 4 &&
+		((str[0] == 'M' && str[1] == 'M' &&
+			str[2] == '\0' && (str[3] == '*' || str[3] == '+')) ||
+		(str[0] == 'I' && str[1] == 'I' &&
+			(str[2] == '*' || str[2] == '+') && str[3] == '\0')) )
 		return( TRUE );
 
 	return( FALSE );
@@ -1915,10 +1934,10 @@ vips__istiff_buffer( void *buf, size_t len )
 gboolean
 vips__istiff( const char *filename )
 {
-	unsigned char buf[2];
+	unsigned char buf[4];
 
-	if( vips__get_bytes( filename, buf, 2 ) &&
-		vips__istiff_buffer( buf, 2 ) )
+	if( vips__get_bytes( filename, buf, 4 ) &&
+		vips__istiff_buffer( buf, 4 ) )
 		return( TRUE );
 
 	return( FALSE );
