@@ -138,6 +138,12 @@
  * 	  of bands, etc., see the tiff loader
  * 26/1/14
  * 	- add RGB as well as YCbCr write
+ * 20/11/14
+ * 	- cache input in tile write mode to keep us sequential
+ * 3/12/14
+ * 	- embed XMP in output
+ * 10/12/14
+ * 	- zero out edge tile buffers before jpeg write, thanks iwbh15
  */
 
 /*
@@ -259,13 +265,15 @@ typedef struct tiff_write {
 	int pyramid;			/* Write pyramid */
 	int onebit;			/* Write as 1-bit TIFF */
         int resunit;                    /* Resolution unit (inches or cm) */
-        float xres;                    	/* Resolution in X */
-        float yres;                    	/* Resolution in Y */
+        double xres;                   	/* Resolution in X */
+        double yres;                   	/* Resolution in Y */
 	char *icc_profile;		/* Profile to embed */
 	int bigtiff;			/* True for bigtiff write */
 	int rgbjpeg;			/* True for RGB not YCbCr */
 
 	GMutex *write_lock;		/* Lock TIFF*() calls with this */
+
+	VipsImage *cache; 		/* Cache a chunk of input */
 } TiffWrite;
 
 /* Open TIFF for output.
@@ -378,6 +386,18 @@ pack2tiff( TiffWrite *tw, VipsRegion *in, VipsPel *q, VipsRect *area )
 {
 	int y;
 
+	/* JPEG compression can read outside the pixel area for edge tiles. It
+	 * always compresses 8x8 blocks, so if the image width or height is
+	 * not a multiple of 8, it can look beyond the pixels we will write.
+	 *
+	 * Black out the tile first to make sure these edge pixels are always
+	 * zero.
+	 */
+	if( tw->compression == COMPRESSION_JPEG &&
+		(area->width < tw->tilew || 
+		 area->height < tw->tileh) )
+		memset( q, 0, TIFFTileSize( tw->tif ) );
+
 	for( y = area->top; y < VIPS_RECT_BOTTOM( area ); y++ ) {
 		VipsPel *p = (VipsPel *) VIPS_REGION_ADDR( in, area->left, y );
 
@@ -402,7 +422,7 @@ static int
 embed_profile_file( TIFF *tif, const char *profile )
 {
 	char *buffer;
-	unsigned int length;
+	size_t length;
 
 	if( !(buffer = vips__file_read_name( profile, VIPS_ICC_DIR, &length )) )
 		return( -1 );
@@ -451,6 +471,28 @@ embed_profile( TiffWrite *tw, TIFF *tif )
 	return( 0 );
 }
 
+/* Embed any XMP metadata. 
+ */
+static int
+embed_xmp( TiffWrite *tw, TIFF *tif )
+{
+	void *data;
+	size_t data_length;
+
+	if( !vips_image_get_typeof( tw->im, VIPS_META_XMP_NAME ) )
+		return( 0 );
+	if( vips_image_get_blob( tw->im, VIPS_META_XMP_NAME, 
+		&data, &data_length ) )
+		return( -1 );
+	TIFFSetField( tif, TIFFTAG_XMLPACKET, data_length, data );
+
+#ifdef DEBUG
+	printf( "vips2tiff: attached XMP from meta\n" );
+#endif /*DEBUG*/
+
+	return( 0 );
+}
+
 /* Write a TIFF header. width and height are the size of the VipsImage we are
  * writing (may have been shrunk!).
  */
@@ -478,14 +520,14 @@ write_tiff_header( TiffWrite *tw, TIFF *tif, int width, int height )
 	 */
 	TIFFSetField( tif, TIFFTAG_RESOLUTIONUNIT, tw->resunit );
 	TIFFSetField( tif, TIFFTAG_XRESOLUTION, 
-		VIPS_CLIP( 0.01, tw->xres, 10000 ) );
+		VIPS_CLIP( 0.01, tw->xres, 1000000 ) );
 	TIFFSetField( tif, TIFFTAG_YRESOLUTION, 
-		VIPS_CLIP( 0.01, tw->yres, 10000 ) );
+		VIPS_CLIP( 0.01, tw->yres, 1000000 ) );
 
-	/* Attach ICC profile.
-	 */
 	if( embed_profile( tw, tif ) )
 		return( -1 );
+	if( embed_xmp( tw, tif ) )
+		return( -1 );
 
 	/* And colour fields.
 	 */
@@ -669,7 +711,8 @@ build_pyramid( TiffWrite *tw, PyramidLayer *above,
 	 */
 	*zap = layer;
 
-	if( layer->width > tw->tilew || layer->height > tw->tileh ) 
+	if( layer->width > tw->tilew || 
+		layer->height > tw->tileh ) 
 		if( build_pyramid( tw, layer, 
 			&layer->below, layer->width, layer->height ) )
 			return( -1 );
@@ -1229,6 +1272,7 @@ free_tiff_write( TiffWrite *tw )
 	VIPS_FREEF( vips_free, tw->tbuf );
 	VIPS_FREEF( vips_g_mutex_free, tw->write_lock );
 	VIPS_FREEF( free_pyramid, tw->layer );
+	VIPS_UNREF( tw->cache );
 	VIPS_FREEF( vips_free, tw->icc_profile );
 }
 
@@ -1320,6 +1364,7 @@ make_tiff_write( VipsImage *im, const char *filename,
 	tw->bigtiff = bigtiff;
 	tw->rgbjpeg = rgbjpeg;
 	tw->write_lock = NULL;
+	tw->cache = NULL;
 
 	tw->resunit = get_resunit( resunit );
 	tw->xres = xres;
@@ -1343,7 +1388,7 @@ make_tiff_write( VipsImage *im, const char *filename,
 	 */
 	if( tw->pyramid ) {
 		if( im->Coding == VIPS_CODING_NONE && 
-			vips_bandfmt_iscomplex( im->BandFmt ) ) {
+			vips_band_format_iscomplex( im->BandFmt ) ) {
 			vips_error( "vips2tiff", 
 				"%s", _( "can only pyramid LABQ and "
 				"non-complex images" ) );
@@ -1379,6 +1424,21 @@ make_tiff_write( VipsImage *im, const char *filename,
 	else
 		tw->tls = VIPS_IMAGE_SIZEOF_PEL( im ) * tw->tilew;
 
+	/* If we will be writing tiles, we need to cache tileh lines of the
+	 * input, since we say we're sequential.
+	 */
+	if( tw->tile ) { 
+		if( vips_tilecache( tw->im, &tw->cache,
+			"tile_width", tw->im->Xsize,
+			"tile_height", 1,
+			"max_tiles", 2 * tw->tileh,
+			"threaded", TRUE,
+			NULL ) )
+			return( NULL );
+
+		tw->im = tw->cache;
+	}
+
 	return( tw );
 }
 
@@ -1445,10 +1505,12 @@ tiff_copy( TiffWrite *tw, TIFF *out, TIFF *in )
 		}
 	}
 
-	/* We can't copy profiles :( Set again from TiffWrite.
+	/* We can't copy profiles or xmp :( Set again from TiffWrite.
 	 */
 	if( embed_profile( tw, out ) )
 		return( -1 );
+	if( embed_xmp( tw, out ) )
+		return( -1 );
 
 	buf = vips_malloc( NULL, TIFFTileSize( in ) );
 	n = TIFFNumberOfTiles( in );
