@@ -108,9 +108,9 @@ int vips_image_get_xoffset( const VipsImage *image );
 int vips_image_get_yoffset( const VipsImage *image );
 const char *vips_image_get_filename( const VipsImage *image );
 const char *vips_image_get_mode( const VipsImage *image );
-double vips_image_get_scale( const VipsImage *array );
-double vips_image_get_offset( const VipsImage *array );
-void *vips_image_get_data( VipsImage *image );
+double vips_image_get_scale( const VipsImage *image );
+double vips_image_get_offset( const VipsImage *image );
+const void *vips_image_get_data( VipsImage *image );
 
 void vips_image_init_fields( VipsImage *image, 
 	int xsize, int ysize, int bands, 
