@@ -4,15 +4,16 @@
 #ifndef VIPS_VERSION_H
 #define VIPS_VERSION_H
 
-#define VIPS_VERSION		"7.40.11"
-#define VIPS_VERSION_STRING	"7.40.11-Wed Oct  8 12:44:50 BST 2014"
+#define VIPS_VERSION		"7.42.1"
+#define VIPS_VERSION_STRING	"7.42.1-Sat Dec 27 10:01:21 GMT 2014"
 #define VIPS_MAJOR_VERSION	(7)
-#define VIPS_MINOR_VERSION	(40)
-#define VIPS_MICRO_VERSION	(11)
+#define VIPS_MINOR_VERSION	(42)
+#define VIPS_MICRO_VERSION	(1)
 
 /* Not really anything to do with versions, but this is a handy place to put
  * it.
  */
 #define VIPS_EXEEXT ""
+#define VIPS_ENABLE_DEPRECATED 1
 
 #endif /*VIPS_VERSION_H*/
