@@ -179,7 +179,7 @@
  * #VIPS_DEMAND_STYLE_FATSTRIP --- This operation would like to output strips 
  * the width of the image and as high as possible. This option is suitable 
  * for area operations which do not violently transform coordinates, such 
- * as im_conv(). 
+ * as vips_conv(). 
  *
  * #VIPS_DEMAND_STYLE_SMALLTILE --- This is the most general demand format.
  * Output is demanded in small (around 100x100 pel) sections. This style works 
@@ -187,7 +187,7 @@
  *
  * #VIPS_DEMAND_STYLE_ANY --- This image is not being demand-read from a disc 
  * file (even indirectly) so any demand style is OK. It's used for things like
- * im_black() where the pixels are calculated.
+ * vips_black() where the pixels are calculated.
  *
  * See also: vips_image_pipelinev().
  */
@@ -1736,6 +1736,54 @@ vips_image_new_memory( void )
 	return( vips_image_new_mode( vips_image_temp_name(), "t" ) );
 }
 
+/**
+ * vips_filename_get_filename:
+ * @vips_filename: a filename including a set of options
+ *
+ * Given a vips filename like "fred.jpg[Q=90]", return a new string of
+ * just the filename part, "fred.jpg" in this case. 
+ *
+ * Useful for language bindings. 
+ *
+ * See also: vips_filename_get_options().
+ *
+ * Returns: transfer full: just the filename component.
+ */
+char *
+vips_filename_get_filename( const char *vips_filename )
+{
+	char filename[VIPS_PATH_MAX];
+	char options[VIPS_PATH_MAX];
+
+	vips__filename_split8( vips_filename, filename, options ); 
+
+	return( g_strdup( filename ) );
+}
+
+/**
+ * vips_filename_get_options:
+ * @vips_filename: a filename including a set of options
+ *
+ * Given a vips filename like "fred.jpg[Q=90]", return a new string of
+ * just the options part, "[Q=90]" in this case. 
+ *
+ * Useful for language bindings. 
+ *
+ * See also: vips_filename_get_filename().
+ *
+ * Returns: transfer full: just the options component.
+ */
+char *
+vips_filename_get_options( const char *vips_filename )
+{
+	char filename[VIPS_PATH_MAX];
+	char options[VIPS_PATH_MAX];
+
+	vips__filename_split8( vips_filename, filename, options ); 
+
+	return( g_strdup( options ) );
+}
+
 /**
  * vips_image_new_from_file:
  * @name: file to open
@@ -1745,7 +1793,6 @@ vips_image_new_memory( void )
  *
  * @access: hint #VipsAccess mode to loader
  * @disc: load via a temporary disc file
- * @...: other arguments depend on the loader
  *
  * vips_image_new_from_file() opens @name for reading. It can load files
  * in many image formats, including VIPS, TIFF, PNG, JPEG, FITS, Matlab,
@@ -1754,6 +1801,7 @@ vips_image_new_memory( void )
  * Load options may be appended to @filename as "[name=value,...]" or given as
  * a NULL-terminated list of name-value pairs at the end of the arguments.
  * Options given in the function call override options given in the filename. 
+ * Many loaders add extra options, see vips_jpegload(), for example. 
  *
  * vips_image_new_from_file() always returns immediately with the header
  * fields filled in. No pixels are actually read until you first access them. 
@@ -1896,11 +1944,12 @@ vips_image_new_from_file_raw( const char *filename,
 
 /**
  * vips_image_new_from_memory:
- * @buffer: start of memory area
- * @xsize: image width
- * @ysize: image height
+ * @data: (array length=size) (element-type guint8) (transfer full): start of memory area
+ * @size: length of memory area
+ * @width: image width
+ * @height: image height
  * @bands: image bands (or bytes per pixel)
- * @bandfmt: image format
+ * @format: image format
  *
  * This function wraps a #VipsImage around a memory area. The memory area
  * must be a simple array, for example RGBRGBRGB, left-to-right,
@@ -1918,8 +1967,8 @@ vips_image_new_from_file_raw( const char *filename,
  * Returns: the new #VipsImage, or %NULL on error.
  */
 VipsImage *
-vips_image_new_from_memory( void *buffer, 
-	int xsize, int ysize, int bands, VipsBandFormat bandfmt )
+vips_image_new_from_memory( void *data, size_t size,
+	int width, int height, int bands, VipsBandFormat format )
 {
 	VipsImage *image;
 
@@ -1929,17 +1978,30 @@ vips_image_new_from_memory( void *buffer,
 	g_object_set( image,
 		"filename", vips_image_temp_name(),
 		"mode", "m",
-		"foreign_buffer", buffer,
-		"width", xsize,
-		"height", ysize,
+		"foreign_buffer", data,
+		"width", width,
+		"height", height,
 		"bands", bands,
-		"format", bandfmt,
+		"format", format,
 		NULL );
 	if( vips_object_build( VIPS_OBJECT( image ) ) ) {
 		VIPS_UNREF( image );
 		return( NULL );
 	}
 
+	/* Allow len == 0, meaning don't check. Used for im_image()
+	 * compatibility.
+	 */
+	if( size > 0 && 
+		size < VIPS_IMAGE_SIZEOF_IMAGE( image ) ) {
+		vips_error( "VipsImage",
+			_( "buffer too small --- "
+				"should be %zd bytes, you passed %zd" ),
+			VIPS_IMAGE_SIZEOF_IMAGE( image ), size ); 
+		VIPS_UNREF( image );
+		return( NULL );
+	}
+
 	return( image );
 }
 
@@ -1972,7 +2034,7 @@ vips_image_new_from_buffer( void *buf, size_t len,
 	const char *option_string, ... )
 {
 	const char *operation_name;
-	VipsArea *area;
+	VipsBlob *blob;
 	va_list ap;
 	int result;
 	VipsImage *out;
@@ -1984,14 +2046,14 @@ vips_image_new_from_buffer( void *buf, size_t len,
 
 	/* We don't take a copy of the data or free it.
 	 */
-	area = vips_area_new_blob( NULL, buf, len );
+	blob = vips_blob_new( NULL, buf, len );
 
 	va_start( ap, option_string );
 	result = vips_call_split_option_string( operation_name, 
-		option_string, ap, area, &out );
+		option_string, ap, blob, &out );
 	va_end( ap );
 
-	vips_area_unref( area );
+	vips_area_unref( VIPS_AREA( blob ) );
 
 	if( result )
 		return( NULL );
@@ -2079,6 +2141,44 @@ vips_image_new_matrixv( int width, int height, ... )
 	return( matrix ); 
 }
 
+/**
+ * vips_image_new_matrix_from_array:
+ * @width: image width
+ * @height: image height
+ * @array: (array length=size) (transfer none): array of elements
+ * @size: number of elements
+ *
+ * A binding-friendly version of vips_image_new_matrixv().
+ *
+ * Returns: the new #VipsImage, or %NULL on error.
+ */
+VipsImage *
+vips_image_new_matrix_from_array( int width, int height, 
+	double *array, int size )
+{
+	VipsImage *matrix;
+	int x, y;
+	int i;
+
+	if( size != width * height ) {
+		vips_error( "VipsImage",
+			_( "bad array length --- should be %d, you passed %d" ),
+			width * height, size );
+		return( NULL );
+	}
+
+	vips_check_init();
+
+	matrix = vips_image_new_matrix( width, height ); 
+
+	i = 0;
+	for( y = 0; y < height; y++ )
+		for( x = 0; x < width; x++ )
+			*VIPS_MATRIX( matrix, x, y ) = array[i++];
+
+	return( matrix ); 
+}
+
 /**
  * vips_image_set_delete_on_close:
  * @image: image to set
@@ -2104,6 +2204,46 @@ vips_image_set_delete_on_close( VipsImage *image, gboolean delete_on_close )
 		VIPS_SETSTR( image->delete_on_close_filename, image->filename );
 }
 
+/**
+ * vips_get_disc_threshold:
+ *
+ * Return the number of bytes at which we flip between open via memory and
+ * open via disc. This defaults to 100mb, but can be changed with the
+ * VIPS_DISC_THRESHOLD environment variable or the --vips-disc-threshold
+ * command-line flag. See vips_image_new_from_file(). 
+ *
+ * Returns: disc threshold in bytes.
+ */
+guint64
+vips_get_disc_threshold( void )
+{
+	static gboolean done = FALSE;
+	static guint64 threshold;
+
+	if( !done ) {
+		const char *env;
+
+		done = TRUE;
+
+		/* 100mb default.
+		 */
+		threshold = 100 * 1024 * 1024;
+
+		if( (env = g_getenv( "VIPS_DISC_THRESHOLD" )) || 
+			(env = g_getenv( "IM_DISC_THRESHOLD" )) ) 
+			threshold = vips__parse_size( env );
+
+		if( vips__disc_threshold ) 
+			threshold = vips__parse_size( vips__disc_threshold );
+
+#ifdef DEBUG
+		printf( "vips_get_disc_threshold: %zd bytes\n", threshold );
+#endif /*DEBUG*/
+	}
+
+	return( threshold );
+}
+
 /**
  * vips_image_new_temp_file:
  * @format: format of file
@@ -2244,8 +2384,8 @@ vips_image_write_to_file( VipsImage *image, const char *name, ... )
  * vips_image_write_to_buffer:
  * @in: image to write
  * @suffix: format to write 
- * @buf: return buffer start here
- * @len: return buffer length here
+ * @buf: (array length=size) (element-type guint8) (transfer full): return buffer start here
+ * @size: return buffer length here
  * @...: %NULL-terminated list of optional named arguments
  *
  * Writes @in to a memory buffer in a format specified by @suffix. 
@@ -2265,34 +2405,34 @@ vips_image_write_to_file( VipsImage *image, const char *name, ... )
  */
 int
 vips_image_write_to_buffer( VipsImage *in, 
-	const char *name, void **buf, size_t *len, 
+	const char *suffix, void **buf, size_t *size, 
 	... )
 {
-	char suffix[VIPS_PATH_MAX];
+	char filename[VIPS_PATH_MAX];
 	char option_string[VIPS_PATH_MAX];
 	const char *operation_name;
-	VipsArea *area;
+	VipsBlob *blob;
 	va_list ap;
 	int result;
 
-	vips__filename_split8( name, suffix, option_string );
-	if( !(operation_name = vips_foreign_find_save_buffer( suffix )) )
+	vips__filename_split8( suffix, filename, option_string );
+	if( !(operation_name = vips_foreign_find_save_buffer( filename )) )
 		return( -1 );
 
-	va_start( ap, len );
+	va_start( ap, size );
 	result = vips_call_split_option_string( operation_name, option_string, 
-		ap, in, &area );
+		ap, in, &blob );
 	va_end( ap );
 
-	if( area ) { 
+	if( blob ) { 
 		if( buf ) {
-			*buf = area->data;
-			area->free_fn = NULL;
+			*buf = VIPS_AREA( blob )->data;
+			VIPS_AREA( blob )->free_fn = NULL;
 		}
-		if( len ) 
-			*len = area->length;
+		if( size ) 
+			*size = VIPS_AREA( blob )->length;
 
-		vips_area_unref( area );
+		vips_area_unref( VIPS_AREA( blob ) );
 	}
 
 	return( result );
@@ -2301,51 +2441,47 @@ vips_image_write_to_buffer( VipsImage *in,
 /**
  * vips_image_write_to_memory:
  * @in: image to write
- * @buf: (transfer full): return buffer start here
- * @len: return buffer length here
+ * @size: return buffer length here
  *
  * Writes @in to memory as a simple, unformatted C-style array. 
  *
- * The caller is responsible for freeing memory. 
+ * The caller is responsible for freeing this memory. 
  *
  * See also: vips_image_write_to_buffer().
  *
- * Returns: 0 on success, -1 on error
+ * Returns: (array length=size) (element-type guint8) (transfer full): return buffer start here
  */
-int
-vips_image_write_to_memory( VipsImage *in, void **buf_out, size_t *len_out )
+void *
+vips_image_write_to_memory( VipsImage *in, size_t *size_out )
 {
 	void *buf;
-	size_t len;
+	size_t size;
 	VipsImage *x;
 
-	g_assert( buf_out ); 
-
-	len = VIPS_IMAGE_SIZEOF_IMAGE( in );
-	if( !(buf = g_try_malloc( len )) ) {
+	size = VIPS_IMAGE_SIZEOF_IMAGE( in );
+	if( !(buf = g_try_malloc( size )) ) {
 		vips_error( "vips_image_write_to_memory", 
 			_( "out of memory --- size == %dMB" ), 
-			(int) (len / (1024.0 * 1024.0))  );
+			(int) (size / (1024.0 * 1024.0))  );
 		vips_warn( "vips_image_write_to_memory", 
 			_( "out of memory --- size == %dMB" ), 
-			(int) (len / (1024.0*1024.0))  );
-		return( -1 );
+			(int) (size / (1024.0*1024.0))  );
+		return( NULL );
 	}
 
-	x = vips_image_new_from_memory( buf, 
+	x = vips_image_new_from_memory( buf, size,
 		in->Xsize, in->Ysize, in->Bands, in->BandFmt );
 	if( vips_image_write( in, x ) ) {
 		g_object_unref( x );
 		g_free( buf ); 
-		return( -1 ); 
+		return( NULL ); 
 	}
 	g_object_unref( x );
 
-	*buf_out = buf;
-	if( len_out )
-		*len_out = len;
+	if( size_out )
+		*size_out = size;
 
-	return( 0 ); 
+	return( buf ); 
 }
 
 /**
@@ -2396,23 +2532,23 @@ vips_image_decode( VipsImage *in, VipsImage **out )
  * See also: vips_image_decode().
  */
 int
-vips_image_decode_predict( VipsImage *im, 
+vips_image_decode_predict( VipsImage *in, 
 	int *out_bands, VipsBandFormat *out_format )
 {
 	VipsBandFormat format;
 	int bands; 
 
-	if( im->Coding == VIPS_CODING_LABQ ) {
+	if( in->Coding == VIPS_CODING_LABQ ) {
 		bands = 3;
 		format = VIPS_FORMAT_FLOAT;
 	}
-	else if( im->Coding == VIPS_CODING_RAD ) {
+	else if( in->Coding == VIPS_CODING_RAD ) {
 		bands = 3;
 		format = VIPS_FORMAT_FLOAT;
 	}
 	else {
-		bands = im->Bands;
-		format = im->BandFmt;
+		bands = in->Bands;
+		format = in->BandFmt;
 	}
 
 	if( out_bands )
@@ -2585,7 +2721,7 @@ vips_image_write_prepare( VipsImage *image )
  * @linebuffer: scanline of pixels
  *
  * Write a line of pixels to an image. This function must be called repeatedly
- * with @ypos increasing from 0 to #VipsImage.height .
+ * with @ypos increasing from 0 to #VipsImage::height .
  * @linebuffer must be VIPS_IMAGE_SIZEOF_LINE() bytes long.
  *
  * See also: vips_image_generate().
@@ -2789,7 +2925,7 @@ vips_image_wio_input( VipsImage *image )
 
 		/* We need to zap any start/gen/stop callbacks. If we don't,
 		 * calling vips_region_prepare_to() later to read from this 
-		 * image will fail, since it will think it need to create the
+		 * image will fail, since it will think it needs to create the
 		 * image, not read from it.
 		 */
 		image->start_fn = NULL;
