@@ -105,10 +105,10 @@ int vips__leak = 0;
 /**
  * vips_get_argv0:
  *
- * See also: vips_init().
+ * See also: VIPS_INIT().
  *
  * Returns: a pointer to an internal copy of the argv0 string passed to
- * vips_init(). Do not free this value
+ * VIPS_INIT(). Do not free this value
  */
 const char *
 vips_get_argv0( void )
@@ -118,12 +118,12 @@ vips_get_argv0( void )
 
 /**
  * VIPS_INIT:
- * @argv0: name of application
+ * @ARGV0: name of application
  *
  * VIPS_INIT() starts up the world of VIPS. You should call this on
  * program startup before using any other VIPS operations. If you do not call
  * VIPS_INIT(), VIPS will call it for you when you use your first VIPS 
- * operation, but it may not be able to get hold of @argv0 and VIPS may 
+ * operation, but it may not be able to get hold of @ARGV0 and VIPS may 
  * therefore be unable to find its data files. It is much better to call 
  * this macro yourself.
  *
@@ -166,12 +166,79 @@ vips_get_argv0( void )
  * Returns: 0 on success, -1 otherwise
  */
 
-/* vips_init() is a macro which checks library and application
- * compatibility before calling vips__init().
+/* Load all plugins in a directory ... look for '.plg' suffix. Error if we had
+ * any probs.
+ */
+static int
+vips_load_plugins( const char *fmt, ... )
+{
+        va_list ap;
+        char dir_name[VIPS_PATH_MAX];
+        GDir *dir;
+	const char *name;
+        int result;
+
+	/* Silently succeed if we can't do modules.
+	 */
+	if( !g_module_supported() )
+		return( 0 );
+
+        va_start( ap, fmt );
+        (void) vips_vsnprintf( dir_name, VIPS_PATH_MAX - 1, fmt, ap );
+        va_end( ap );
+
+#ifdef DEBUG
+	printf( "vips_load_plugins: searching \"%s\"\n", dir_name );
+#endif /*DEBUG*/
+
+        if( !(dir = g_dir_open( dir_name, 0, NULL )) ) 
+		/* Silent success for dir not there.
+		 */
+                return( 0 );
+
+        result = 0;
+        while( (name = g_dir_read_name( dir )) )
+                if( vips_ispostfix( name, ".plg" ) ) { 
+			char path[VIPS_PATH_MAX];
+			GModule *module;
+
+			vips_snprintf( path, VIPS_PATH_MAX - 1, 
+				"%s" G_DIR_SEPARATOR_S "%s", dir_name, name );
+
+#ifdef DEBUG
+			printf( "vips_load_plugins: loading \"%s\"\n", path );
+#endif /*DEBUG*/
+
+			module = g_module_open( path, G_MODULE_BIND_LAZY );
+			if( !module ) {
+				vips_warn( "vips_init", 
+					_( "unable to load \"%s\" -- %s" ), 
+					path, 
+					g_module_error() ); 
+				result = -1;
+			}
+                }
+        g_dir_close( dir );
+
+	return( result );
+}
+
+/**
+ * vips_init:
+ * @argv0: name of application
+ *
+ * This function starts up libvips, see VIPS_INIT(). 
+ *
+ * This function is for bindings which need to start up vips. C programs
+ * should use the VIPS_INIT() macro, which does some extra checks. 
+ *
+ * See also: VIPS_INIT(). 
+ *
+ * Returns: 0 on success, -1 otherwise
  */
 
 int
-vips__init( const char *argv0 )
+vips_init( const char *argv0 )
 {
 	extern GType vips_system_get_type( void );
 
@@ -276,9 +343,15 @@ vips__init( const char *argv0 )
 	vips_draw_operation_init();
 	vips_mosaicing_operation_init();
 
-	/* Load up any plugins in the vips libdir. We don't error on failure,
-	 * it's too annoying to have VIPS refuse to start because of a broken
-	 * plugin.
+	/* Load any vips8 plugins from the vips libdir. Keep going, even if
+	 * some plugins fail to load. 
+	 */
+	(void) vips_load_plugins( "%s/vips-plugins-%d.%d", 
+		libdir, VIPS_MAJOR_VERSION, VIPS_MINOR_VERSION );
+
+	/* Load up any vips7 plugins in the vips libdir. We don't error on 
+	 * failure, it's too annoying to have VIPS refuse to start because of 
+	 * a broken plugin.
 	 */
 	if( im_load_plugins( "%s/vips-%d.%d", 
 		libdir, VIPS_MAJOR_VERSION, VIPS_MINOR_VERSION ) ) {
@@ -294,10 +367,6 @@ vips__init( const char *argv0 )
 		vips_error_clear();
 	}
 
-	/* Build classes which wrap old vips7 operations.
-	 */
-	vips__init_wrap7_classes();
-
 	/* Start up the buffer cache.
 	 */
 	vips__buffer_init();
@@ -349,7 +418,7 @@ vips_check_init( void )
 	 * for old programs which are missing an vips_init() call. We need
 	 * i18n set up before we can translate.
 	 */
-	if( vips__init( "vips" ) )
+	if( vips_init( "vips" ) )
 		vips_error_clear();
 }
 
@@ -379,8 +448,8 @@ vips_leak( void )
 	vips__type_leak();
 
 #ifdef DEBUG
-#endif /*DEBUG*/
 	vips_buffer_dump_all();
+#endif /*DEBUG*/
 }
 
 /**
@@ -561,30 +630,17 @@ static GOptionEntry option_entries[] = {
 };
 
 /**
- * vips_get_option_group: (skip)
+ * vips_add_option_entries: 
+ * @option_group: group to add to
  *
- * vips_get_option_group() returns a %GOptionGroup containing various VIPS
- * command-line options. It can be used with %GOption to help
- * parse argc/argv.
+ * Add the standard vips %GOptionEntry to a %GOptionGroup. 
  *
- * See also: vips_version(), vips_guess_prefix(),
- * vips_guess_libdir(), vips_init().
- *
- * Returns: a %GOptionGroup for VIPS, see %GOption
+ * See also: g_option_group_new(). 
  */
-GOptionGroup *
-vips_get_option_group( void )
+void
+vips_add_option_entries( GOptionGroup *option_group )
 {
-	static GOptionGroup *option_group = NULL;
-
-	if( !option_group ) {
-		option_group = g_option_group_new( 
-			"vips", _( "VIPS Options" ), _( "Show VIPS options" ),
-			NULL, NULL );
-		g_option_group_add_entries( option_group, option_entries );
-	}
-
-	return( option_group );
+	g_option_group_add_entries( option_group, option_entries );
 }
 
 /* Find the prefix part of a dir ... name is the name of this prog from argv0.
@@ -946,3 +1002,18 @@ vips_version( int flag )
 		return( -1 );
 	}
 }
+
+/**
+ * vips_leak_set:
+ * @leak: turn leak checking on or off
+ *
+ * Turn on or off vips leak checking. See also --vips-leak and
+ * vips_get_option_group(). 
+ *
+ * You should call this very early in your program. 
+ */
+void 
+vips_leak_set( gboolean leak )
+{
+	vips__leak = leak; 
+}
