@@ -58,7 +58,7 @@
  * SECTION: object
  * @short_description: the VIPS base object class
  * @stability: Stable
- * @see_also: <link linkend="libvips-operation">operation</link>
+ * @see_also: <link linkend="VipsOperation">operation</link>
  * @include: vips/vips.h
  *
  * The #VipsObject class and associated types and macros.
@@ -169,6 +169,7 @@
  * @VIPS_ARGUMENT_INPUT: is an input argument (one we depend on)
  * @VIPS_ARGUMENT_OUTPUT: is an output argument (depends on us)
  * @VIPS_ARGUMENT_DEPRECATED: just there for back-compat, hide 
+ * @VIPS_ARGUMENT_MODIFY: the input argument will be modified
  *
  * Flags we associate with each object argument.
  *
@@ -186,6 +187,9 @@
  * looked for if required, are not checked for "have-been-set". You can
  * deprecate a required argument, but you must obviously add a new required
  * argument if you do.
+ *
+ * Input args with @VIPS_ARGUMENT_MODIFY will be modified by the operation.
+ * This is used for things like the in-place drawing operations. 
  */
 
 /* Our signals. 
@@ -359,17 +363,23 @@ vips_object_build( VipsObject *object )
 
 /**
  * vips_object_summary_class: (skip)
+ * @klass: class to summarise
+ * @buf: write summary here
  *
+ * Generate a human-readable summary for a class. 
  */
 void
-vips_object_summary_class( VipsObjectClass *class, VipsBuf *buf )
+vips_object_summary_class( VipsObjectClass *klass, VipsBuf *buf )
 {
-	class->summary_class( class, buf );
+	klass->summary_class( klass, buf );
 }
 
 /**
  * vips_object_summary: (skip)
+ * @object: object to summarise
+ * @buf: write summary here
  *
+ * Generate a human-readable summary for an object. 
  */
 void
 vips_object_summary( VipsObject *object, VipsBuf *buf )
@@ -381,7 +391,10 @@ vips_object_summary( VipsObject *object, VipsBuf *buf )
 
 /**
  * vips_object_dump: (skip)
+ * @object: object to dump
+ * @buf: write dump here
  *
+ * Dump everything that vips knows about an object to a string.
  */
 void
 vips_object_dump( VipsObject *object, VipsBuf *buf )
@@ -787,7 +800,7 @@ vips_object_argument_isset( VipsObject *object, const char *name )
  *
  * Convenience: get the flags for an argument. Useful for bindings.
  *
- * Returns: The #VipsArgmentFlags for this argument.
+ * Returns: The #VipsArgumentFlags for this argument.
  */
 VipsArgumentFlags
 vips_object_get_argument_flags( VipsObject *object, const char *name )
@@ -1166,7 +1179,7 @@ vips_object_set_property( GObject *gobject,
 	printf( ".%s\n", g_param_spec_get_name( pspec ) );
 
 	/* This can crash horribly with some values, have it as a separate
-	 * chunk so we can easily commenmt it out.
+	 * chunk so we can easily comment it out.
 	 */
 {
 	char *str_value;
@@ -1957,7 +1970,7 @@ vips_object_set_argument_from_string( VipsObject *object,
 		g_value_set_enum( &gvalue, i );
 	}
 	else if( G_IS_PARAM_SPEC_FLAGS( pspec ) ) {
-		/* Hard to set from a symbolic name. Just take an int.
+		/* Allow a symbolic name, or an int. 
 		 */
 		int i;
 
@@ -1966,7 +1979,9 @@ vips_object_set_argument_from_string( VipsObject *object,
 			return( -1 );
 		}
 
-		if( sscanf( value, "%d", &i ) != 1 ) {
+		if( sscanf( value, "%d", &i ) != 1 &&
+			(i = vips_flags_from_nick( class->nickname, 
+			otype, value )) < 0 ) {
 			vips_error( class->nickname,
 				_( "'%s' is not an integer" ), value );
 			return( -1 );
@@ -2177,8 +2192,7 @@ vips_object_set_valist( VipsObject *object, va_list ap )
 
 		VIPS_ARGUMENT_COLLECT_SET( pspec, argument_class, ap );
 
-		g_object_set_property( G_OBJECT( object ), 
-			name, &value );
+		g_object_set_property( G_OBJECT( object ), name, &value );
 
 		VIPS_ARGUMENT_COLLECT_GET( pspec, argument_class, ap );
 
@@ -2441,11 +2455,11 @@ vips_object_to_string_optional( VipsObject *object,
 }
 
 /**
- * vips_object_to_string: (skip)
+ * vips_object_to_string: 
  * @object: object to stringify
  * @buf: write string here
  *
- * The inverse of vips_object_new_from_string(): turn an object into eg.
+ * The inverse of vips_object_new_from_string(): turn @object into eg.
  * "VipsInterpolateSnohalo1(blur=.333333)".
  */
 void
@@ -2576,8 +2590,16 @@ vips_type_map_all( GType base, VipsTypeMapFn fn, void *a )
 
 /**
  * vips_class_map_all: (skip) 
+ * @type: base type
+ * @fn: call this function for every type
+ * @a: client data
  *
- * Loop over all the subclasses of a base type. Non-abstract classes only.
+ * Loop over all the subclasses of @type. Non-abstract classes only.
+ * Stop when @fn returns 
+ * non-%NULL and return that value. 
+ *
+ * Returns: %NULL if @fn returns %NULL for all arguments, otherwise the first
+ * non-%NULL value from @fn.
  */
 void *
 vips_class_map_all( GType type, VipsClassMapFn fn, void *a )
@@ -2746,6 +2768,29 @@ vips_type_find( const char *basename, const char *nickname )
 	return( type );
 }
 
+/**
+ * vips_nickname_find:
+ * @type: #GType to search for
+ *
+ * Return the VIPS nickanme for a %GType. Handy for language bindings. 
+ *
+ * Returns: (transfer none): the class nickname. 
+ */
+const char *
+vips_nickname_find( GType type )
+{
+	gpointer p;
+	VipsObjectClass *class;
+
+	if( type &&
+		(p = g_type_class_ref( type )) &&
+		VIPS_IS_OBJECT_CLASS( p ) &&
+		(class = VIPS_OBJECT_CLASS( p )) )
+		return( class->nickname );
+
+	return( NULL );
+}
+
 /* The vips_object_local() macro uses this as its callback.
  */
 void
@@ -2927,12 +2972,18 @@ vips_object_unref_outputs_sub( VipsObject *object,
 	return( NULL );
 }
 
-/* Unref all assigned output objects.
+/**
+ * vips_object_unref_outputs:
+ * @object: object to drop output refs from
+ *
+ * Unref all assigned output objects. Useful for language bindings. 
  *
  * After an object is built, all output args are owned by the caller. If
  * something goes wrong before then, we have to unref the outputs that have
- * been made so far. And this function can also be useful for callers when
+ * been made so far. This function can also be useful for callers when
  * they've finished processing outputs themselves.
+ *
+ * See also: vips_cache_operation_build().
  */
 void
 vips_object_unref_outputs( VipsObject *object )
@@ -2940,3 +2991,26 @@ vips_object_unref_outputs( VipsObject *object )
 	(void) vips_argument_map( object,
 		vips_object_unref_outputs_sub, NULL, NULL );
 }
+
+/**
+ * vips_object_get_description:
+ * @object: object to fetch description from
+ *
+ * Fetch the object description. Useful for language bindings. 
+ *
+ * @object.description is only avaliable after _build(), which can be too
+ * late. This function fetches from the instance, if possible, but falls back
+ * to the class description if we are too early. 
+ * 
+ * Returns: the object description
+ */
+const char *
+vips_object_get_description( VipsObject *object )
+{
+	VipsObjectClass *class = VIPS_OBJECT_GET_CLASS( object );
+
+	if( object->description ) 
+		return( object->description ) ;
+	else
+		return( class->description ) ;
+}
