@@ -52,7 +52,7 @@
  * SECTION: operation
  * @short_description: the VIPS operation base object class
  * @stability: Stable
- * @see_also: <link linkend="libvips-object">object</link>
+ * @see_also: <link linkend="VipsObject">object</link>
  * @include: vips/vips.h
  *
  * The #VipsOperation class and associated types and macros.
@@ -103,11 +103,16 @@
  *   error ..
  * ]|
  *
- * This will invert @im and return it as a new #VipsImage, @t1. As the caller
+ * This will invert @im and return a new #VipsImage, @t1. As the caller
  * of vips_invert(), you are responsible for @t1 and must unref it when you no
  * longer need it. If vips_invert() fails, no @t1 is returned and you don't
  * need to do anything. 
  *
+ * If you don't need to use @im for another operation, 
+ * you can unref @im immediately after the call. If @im is needed to calculate
+ * @t1, vips_invert() will add a ref to @im and automatically drop it when @t1
+ * is unreffed.
+ *
  * Consider running two operations, one after the other. You could write:
  *
  * |[
@@ -148,7 +153,7 @@
  * ## The #VipsOperation cache
  *
  * Because all #VipsObject are immutable, they can be cached. The cache is
- * very simple to use: instead of calling vips_object_build(), instead call 
+ * very simple to use: instead of calling vips_object_build(), call 
  * vips_cache_operation_build(). This function calculates a hash from the
  * operations's input arguments and looks it up in table of all recent
  * operations. If there's a hit, the new operation is unreffed, the old
@@ -160,7 +165,8 @@
 /** 
  * VipsOperationFlags:
  * @VIPS_OPERATION_NONE: no flags
- * @VIPS_OPERATION_SEQUENTIAL: can work sequentially
+ * @VIPS_OPERATION_SEQUENTIAL: can work sequentially with a small buffer
+ * @VIPS_OPERATION_SEQUENTIAL_UNBUFFERED: can work sequentially with no buffer
  * @VIPS_OPERATION_NOCACHE: must not be cached
  * @VIPS_OPERATION_DEPRECATED: a compatibility thing
  *
@@ -567,8 +573,8 @@ vips_operation_new( const char *name )
 	return( operation );
 }
 
-/* Some systems do not have va_copy() ... this might work (it does on MSVC),
- * apparently.
+/* Some systems do not have va_copy() ... this might work (it does on MSVC,
+ * apparently).
  *
  * FIXME ... this should be in configure.in
  */
@@ -645,7 +651,7 @@ vips_operation_get_valist_required( VipsOperation *operation, va_list ap )
 
 			/* It'd be nice to be able to test for arg being a
 			 * valid gobject pointer, since passing in a valid
-			 * pointer, and having us destroy it, is a common
+			 * pointer (and having us destroy it) is a common
 			 * error and a cause of hard-to-find leaks.
 			 *
 			 * Unfortunately, G_IS_OBJECT() can't be given an
@@ -733,9 +739,20 @@ vips_operation_get_valist_optional( VipsOperation *operation, va_list ap )
 	return( 0 );
 }
 
-/* This can change operation to point at an old, cached one.
+/**
+ * vips_call_required_optional:
+ * @operation: the operation to execute
+ * @required: %va_list of required arguments
+ * @optional: NULL-terminated %va_list of name / value pairs 
+ *
+ * This is the main entry point for the C and C++ varargs APIs. @operation 
+ * is executed, supplying @required and @optional arguments. 
+ *
+ * Beware, this can change @operation to point at an old, cached one.
+ *
+ * Returns: 0 on success, -1 on error
  */
-static int
+int
 vips_call_required_optional( VipsOperation **operation,
 	va_list required, va_list optional ) 
 {
@@ -788,7 +805,7 @@ vips_call_by_name( const char *operation_name,
 		return( -1 );
 
 	/* Set str options before vargs options, so the user can't override
-	 * thnigs we set deliberately.
+	 * things we set deliberately.
 	 */
 	if( option_string &&
 		vips_object_set_from_string( VIPS_OBJECT( operation ), 
@@ -820,15 +837,15 @@ vips_call_by_name( const char *operation_name,
 
 /**
  * vips_call:
- * @operation_name:
+ * @operation_name: name of operation to call
  * @...: required args, then a %NULL-terminated list of argument/value pairs
  *
- * vips_call() calls the named operation, passing in required arguments, and
+ * vips_call() calls the named operation, passing in required arguments and
  * then setting any optional ones from the remainder of the arguments as a set
  * of name/value pairs. 
  *
  * For example, vips_embed() takes six required arguments, @in, @out, @x, @y, 
- * @width, @height; and has two optional arguments, @extend and @background.
+ * @width, @height, and has two optional arguments, @extend and @background.
  * You can run it with vips_call() like this: 
  *
  * |[
