@@ -1,4 +1,4 @@
-/* im_affine() ... affine transform with a supplied interpolator.
+/* affine transform with a supplied interpolator.
  *
  * 
  * Copyright N. Dessipris
@@ -419,9 +419,13 @@ vips_affine_build( VipsObject *object )
 		vips_check_vector_length( class->nickname, 
 			affine->oarea->n, 4 ) )
 		return( -1 );
-
-	if( !affine->interpolate )
-		affine->interpolate = vips_interpolate_new( "bilinear" );
+	/* We can't use vips_object_argument_isset(), since it may have been
+	 * set to NULL, see vips_similarity().
+	 */
+	if( !affine->interpolate ) 
+		g_object_set( object, 
+			"interpolate", vips_interpolate_new( "bilinear" ),
+			NULL ); 
 
 	in = resample->in;
 
@@ -625,6 +629,7 @@ vips_affine_init( VipsAffine *affine )
  * @b: transformation matrix coefficient
  * @c: transformation matrix coefficient
  * @d: transformation matrix coefficient
+ * @...: %NULL-terminated list of optional named arguments
  *
  * Optional arguments:
  *
