@@ -75,6 +75,7 @@
 #include <locale.h>
 
 #include <vips/vips.h>
+#include <vips/internal.h>
 
 #define ORIENTATION ("exif-ifd0-Orientation")
 
@@ -150,35 +151,6 @@ static GOptionEntry options[] = {
 	{ NULL }
 };
 
-static VipsAngle 
-get_angle( VipsImage *im )
-{
-	VipsAngle angle;
-	const char *orientation;
-
-	angle = VIPS_ANGLE_0;
-
-	if( vips_image_get_typeof( im, ORIENTATION ) && 
-		!vips_image_get_string( im, ORIENTATION, &orientation ) ) {
-		if( vips_isprefix( "6", orientation ) )
-			angle = VIPS_ANGLE_90;
-		else if( vips_isprefix( "8", orientation ) )
-			angle = VIPS_ANGLE_270;
-		else if( vips_isprefix( "3", orientation ) )
-			angle = VIPS_ANGLE_180;
-
-		/* Other values do rotate + mirror, don't bother handling them
-		 * though, how common can mirroring be. 
-		 *
-		 * See:
-		 *
-		 * http://www.80sidea.com/archives/2316
-		 */
-	}
-
-	return( angle );
-}
-
 /* Calculate the shrink factors. 
  *
  * We shrink in two stages: first, a shrink with a block average. This can
@@ -192,8 +164,8 @@ static int
 calculate_shrink( VipsImage *im, double *residual, 
 	VipsInterpolate *interp )
 {
-	VipsAngle angle = get_angle( im ); 
-	gboolean rotate = angle == VIPS_ANGLE_90 || angle == VIPS_ANGLE_270;
+	VipsAngle angle = vips_autorot_get_angle( im ); 
+	gboolean rotate = angle == VIPS_ANGLE_D90 || angle == VIPS_ANGLE_D270;
 	int width = rotate_image && rotate ? im->Ysize : im->Xsize;
 	int height = rotate_image && rotate ? im->Xsize : im->Ysize;
 	const int window_size =
@@ -517,18 +489,10 @@ thumbnail_shrink( VipsObject *process, VipsImage *in,
 	sigma = ((1.0 / residual) - 0.5) / 1.5;
 	if( residual < 1.0 &&
 		sigma > 0.1 ) { 
-		if( vips_gaussmat( &t[9], sigma, 0.2,
-			"separable", TRUE,
-			"integer", TRUE,
-			NULL ) ||
-			vips_convsep( in, &t[5], t[9], NULL ) )
+		if( vips_gaussblur( in, &t[5], sigma, NULL ) )
 			return( NULL );
 		vips_info( "vipsthumbnail", "anti-alias, sigma %g",
 			sigma );
-#ifdef DEBUG
-		printf( "anti-alias blur matrix is:\n" ); 
-		vips_matrixprint( t[9], NULL ); 
-#endif /*DEBUG*/
 		in = t[5];
 	}
 
@@ -611,7 +575,11 @@ thumbnail_shrink( VipsObject *process, VipsImage *in,
 			out = t[7];
 		}
 
-		in = out;
+		/* If the embedded profile failed and there's no fallback or
+		 * the fallback failed, out will still be NULL.
+		 */
+		if( out )
+			in = out;
 	}
 
 	/* If we are upsampling, don't sharpen, since nearest looks dumb
@@ -663,10 +631,10 @@ static VipsImage *
 thumbnail_rotate( VipsObject *process, VipsImage *im )
 {
 	VipsImage **t = (VipsImage **) vips_object_local_array( process, 2 );
-	VipsAngle angle = get_angle( im );
+	VipsAngle angle = vips_autorot_get_angle( im );
 
 	if( rotate_image &&
-		angle != VIPS_ANGLE_0 ) {
+		angle != VIPS_ANGLE_D0 ) {
 		/* Need to copy to memory, we have to stay seq.
 		 */
 		t[0] = vips_image_new_memory();
@@ -699,10 +667,15 @@ thumbnail_write( VipsObject *process, VipsImage *im, const char *filename )
 	if( (p = strrchr( file, '.' )) ) 
 		*p = '\0';
 
+	/* Don't use vips_snprintf(), we only want to optionally substitute a 
+	 * single %s.
+	 */
+	vips_strncpy( buf, output_format, FILENAME_MAX ); 
+	vips__substitute( buf, FILENAME_MAX, file ); 
+
 	/* output_format can be an absolute path, in which case we discard the
 	 * path from the incoming file.
 	 */
-	vips_snprintf( buf, FILENAME_MAX, output_format, file );
 	if( g_path_is_absolute( output_format ) ) 
 		output_name = g_strdup( buf );
 	else {
@@ -754,10 +727,11 @@ int
 main( int argc, char **argv )
 {
 	GOptionContext *context;
+	GOptionGroup *main_group;
 	GError *error = NULL;
 	int i;
 
-	if( vips__init( argv[0] ) )
+	if( VIPS_INIT( argv[0] ) )
 	        vips_error_exit( "unable to start VIPS" );
 	textdomain( GETTEXT_PACKAGE );
 	setlocale( LC_ALL, "" );
@@ -770,8 +744,11 @@ main( int argc, char **argv )
 
         context = g_option_context_new( _( "- thumbnail generator" ) );
 
-	g_option_context_add_main_entries( context, options, GETTEXT_PACKAGE );
-	g_option_context_add_group( context, vips_get_option_group() );
+	main_group = g_option_group_new( NULL, NULL, NULL, NULL, NULL );
+	g_option_group_add_entries( main_group, options );
+	vips_add_option_entries( main_group ); 
+	g_option_group_set_translation_domain( main_group, GETTEXT_PACKAGE );
+	g_option_context_set_main_group( context, main_group );
 
 	if( !g_option_context_parse( context, &argc, &argv, &error ) ) {
 		if( error ) {
